==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/plugins/vectorshape/VectorShapePlugin.cpp <==
/* This file is part of the KDE project
 *
 * Copyright (C) 2009 Inge Wallin <inge@lysator.liu.se>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */


// Own
#include "VectorShapePlugin.h"

// KDE
#include <kpluginfactory.h>

// Calligra libs
#include <KoShapeRegistry.h>
#include <KoToolRegistry.h>

// VectorShape
#include "VectorToolFactory.h"
#include "VectorShapeFactory.h"


K_PLUGIN_FACTORY(VectorShapePluginFactory, registerPlugin<VectorShapePlugin>();)
K_EXPORT_PLUGIN(VectorShapePluginFactory("VectorShape"))

VectorShapePlugin::VectorShapePlugin(QObject * parent, const QVariantList &)
    : QObject(parent)
{
    KoToolRegistry::instance()->add(new VectorToolFactory());
    KoShapeRegistry::instance()->add(new VectorShapeFactory());
}

#include <VectorShapePlugin.moc>

==> calligra_2.9.7.orig.tar.xz: calligra-2.9.7/plugins/vectorshape/VectorShapePlugin.cpp <==
/* This file is part of the KDE project
 *
 * Copyright (C) 2009 Inge Wallin <inge@lysator.liu.se>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */


// Own
#include "VectorShapePlugin.h"

// KDE
#include <kpluginfactory.h>

// Calligra libs
#include <KoShapeRegistry.h>
#include <KoToolRegistry.h>

// VectorShape
#include "VectorToolFactory.h"
#include "VectorShapeFactory.h"


K_PLUGIN_FACTORY(VectorShapePluginFactory, registerPlugin<VectorShapePlugin>();)
K_EXPORT_PLUGIN(VectorShapePluginFactory("calligra_shape_vector"))

VectorShapePlugin::VectorShapePlugin(QObject * parent, const QVariantList &)
    : QObject(parent)
{
    KoToolRegistry::instance()->add(new VectorToolFactory());
    KoShapeRegistry::instance()->add(new VectorShapeFactory());
}

#include <VectorShapePlugin.moc>
